@@ -40,7 +40,7 @@ ex_data_table.relop_select_rows <- function(optree,
                 }, character(1))
   src <- paste0(tmpnam, "[ ", paste(src, collapse = " & "), " ]")
   expr <- parse(text = src)
-  tmpenv <- new.env(parent = env)
+  tmpenv <- patch_global_child_env(env)
   assign(tmpnam, x, envir = tmpenv)
   eval(expr, envir = tmpenv, enclos = tmpenv)
 }
